指环王3：王者无敌 (豆瓣)
Description: 指环王3：王者无敌电影简介和剧情介绍,指环王3：王者无敌影评、图片、预告片、影讯、论坛、在线购票
Keywords: 指环王3：王者无敌,The Lord of the Rings: The Return of the King,指环王3：王者无敌影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.32豆瓣电影Top250

# 指环王3：王者无敌 The Lord of the Rings: The Return of the King (2003)

导演: 彼得·杰克逊
编剧: 弗兰·威尔士 / 菲利帕·鲍恩斯 / 彼得·杰克逊 / J. R. R. 托尔金
主演: 伊利亚·伍德 / 西恩·奥斯汀 / 维果·莫腾森 / 奥兰多·布鲁姆 / 伊恩·麦克莱恩 / 肖恩·宾 / 多米尼克·莫纳汉 / 丽芙·泰勒 / 约翰·贝西 / 凯特·布兰切特 / 比利·博伊德 / 萨德文·布罗菲 / 阿利斯泰尔·布朗宁 / 马尔顿·索克斯 / 伯纳德·希尔 / 伊安·霍姆 / 布鲁斯·霍普金斯 / Ian Hughes / 劳伦斯·马克奥雷 / 诺埃尔·阿普利比 / 布雷特·麦肯齐 / Alexandra Astin / Sarah McLeod / Maisy McLeod-Riera / 约翰·诺贝尔 / Paul Norell / 米兰达·奥图 / 布鲁斯·菲利普斯 / 沙恩·朗吉 / 约翰·瑞斯-戴维斯 / Todd Rippon / 安迪·瑟金斯 / Harry Sinclair / 乔尔·托贝克 / 卡尔·厄本 / 史蒂芬·乌瑞 / 雨果·维文 / 大卫·文翰 / 阿兰·霍华德 / 萨拉·贝克 / Robert Pollock / 佩特·史密斯 / 杰德·布罗菲 / 菲利普·格里夫 / 布拉德·道里夫 / 克里斯托弗·李 / 布鲁斯·斯宾斯 / 吉诺·阿赛维多 / Jarl Benzon / Jørn Benzon / Robert Catto / Michael Elsworth / 彼得·杰克逊 / Sandro Kopp / 安德鲁·莱斯尼 / 约瑟夫·米卡-亨特 / 亨利·莫腾森 / 克雷格·帕克 / 克里斯蒂安·瑞沃斯 / 迈克尔·斯曼内科 / 霍华德·肖 / 约翰·斯蒂芬森 / 理查德·泰勒
类型: 剧情 / 动作 / 奇幻 / 冒险
官方网站: www.lordoftherings.net/
制片国家/地区: 美国 / 新西兰
语言: 英语 / 昆雅语 / 古英语 / 辛达林语
上映日期: 2004-03-12(中国大陆) / 2021-05-14(中国大陆重映) / 2003-12-17(美国)
片长: 201分钟 / 254分钟(加长版) / 263分钟(蓝光加长版)
又名: 魔戒三部曲：王者再临(台/港) / 指环王III：王者无敌 / 魔戒3：王者归来 / 指环王3：国王归来 / 指环王3：皇上回宫(豆友译名)
IMDb: tt0167260
豆瓣评分
引用
9.3
762436人评价
5星
70.2%
4星
24.1%
3星
5.1%
2星
0.4%
1星
0.2%
好于 99% 奇幻片
好于 99% 剧情片
想看 看过
评价:
推荐

## 指环王3：王者无敌的剧情简介 · · · · · ·

魔幻战争逐渐进入高潮阶段。霍比特人佛罗多（伊利亚·伍德 Elijah Wood 饰）携带着魔戒，与伙伴山姆（西恩·奥斯汀 Sean Astin 饰）以及狡猾阴暗的咕噜等前往末日山，一路上艰难险阻不断，魔君索伦为阻止魔戒被销毁用尽全力阻挠。另一方面，白袍巫师甘道夫（伊恩·麦克莱恩 Ian McKellen 饰）率中土勇士们镇守刚铎首都——白城米那斯提里斯。魔兽大军压境，黑暗与光明的决战即将来临……
本片是“指环王三部曲”的终结篇，根据英国作家J.R.R.托尔金（J.R.R. Tolkien）同名魔幻巨著《指环王》（The Lord of the Rings）改编，并荣获2004年第76届奥斯卡最佳影片、最佳导演、最佳改编剧本、最佳剪辑、最佳艺术指导、最佳服装设计、最佳化妆、最佳视觉效果、最佳音效、最佳配乐和最佳歌曲等11项大奖。 ©豆瓣

## 指环王3：王者无敌的演职员 · · · · · · ( 全部 166 )

- 彼得·杰克逊 导演
- 伊利亚·伍德 饰 Frodo
- 西恩·奥斯汀 饰 Sam
- 维果·莫腾森 饰 Aragorn
- 奥兰多·布鲁姆 饰 Legolas
- 伊恩·麦克莱恩 饰 Gandalf

## 指环王3：王者无敌的视频和图片 · · · · · · ( 预告片3 | 添加视频评论 | 图片1268 · 添加 )

## 指环王3：王者无敌的获奖情况 · · · · · · ( 全部 )

- 第76届奥斯卡金像奖
- 最佳影片
- 巴里·M·奥斯本 / 弗兰·威尔士 / 彼得·杰克逊

- 第61届金球奖
- 电影类 最佳剧情片

- 第57届英国电影学院奖
- 电影奖 最佳影片
- 巴里·M·奥斯本 / 彼得·杰克逊 / 弗兰·威尔士

## 喜欢这部电影的人也喜欢 · · · · · ·

  指环王2：双塔奇兵

  霍比特人2：史矛革之战

  加勒比海盗

  哈利·波特与魔法石

  勇敢的心

  少年派的奇幻漂流

  大鱼

  角斗士

  拯救大兵瑞恩

  阿凡达

我要写短评

## 指环王3：王者无敌的短评 · · · · · · ( 全部 109384 条 )

热门 / 最新 / 好友

### 7426 有用 如小果 看过 2011-09-07 22:24:43

即使在一起喝过多少次酒，逛过多少次街，掏过多少次心窝，共度过多少时光，许多人还是没能拥有一个能背起你从地狱走向天堂的朋友——山姆。

### 5702 有用 无所谓 看过 2010-06-21 23:33:10

我就不明白甘道夫升级为白袍巫师了怎么不爱使魔法，改成肉搏战士了。一直期待他使一招毁天灭地……

### 5578 有用 草威 看过 2017-01-09 22:13:52

最服的就是山姆了，走了那么长的路，路上吃得那么少，一点儿没瘦。

### 3796 有用 饭夫斯基 看过 2011-10-16 21:29:18

骑白马的不一定是王子，是甘道夫；精灵战斗的时候，导演不会毁了他的美貌，别提莱戈拉斯了；裹着蜘蛛丝的弗罗多就像埃及艳后克娄巴特拉；胖子是重要的，他们可以背你；俩人被困在末日火山上，我说要有鹰，于是有鹰了；我差点以为阿拉贡要迎娶莱戈拉斯；弗罗多和山姆是真爱，绝逼的真爱。我要再看原著。

### 3143 有用 眼角的花朵 看过 2008-06-24 16:55:45

与咕鲁相比，弗罗多是幸运的。他具有别人无可比拟的强大的纯真力量。但他毁灭了魔戒，却无法清除内心被唤醒的邪恶。谁能说在故事最后他远渡海外，不是一种高傲的自我放逐？也许在索伦被消灭的那一刻，他也明白了邪恶的不可战胜。只是不得不与之抗争是英雄的使命。

> 更多短评 109384条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 指环王3：王者无敌的影评 · · · · · · ( 全部 1026 条 )

热门 / 最新 / 好友
熊掌 2006-05-18 01:26:33

## 有些伤口无法愈合

有些伤口永远无法愈合 　　 　　国王归来，美人在怀。《指环王》三部曲最终在一曲《Into The West》声中，以近乎完美的姿势谢幕。 　　让那些制作人员欢呼吧。这确是一次电影特技的胜利。恢宏的史诗气度、壮阔的战争画面、诡异的魔幻场景，正是因为电脑特技的... (展开)
2731 81 152回应 收起
软泥 2007-05-24 12:31:41

## 最爱——魔戒

看过一篇魔戒迷的文章，关于她两次去影院看[The Return the King]的朝圣之路。我最难忘的是她在片末，字幕起的时候，起身向荧幕鞠躬，泪流满面。 她说; 对戒迷来说，一个世纪的等待结束了，对电影来说，七年的等待结束了。那么漫长的时间里，友情诞生了，爱情诞生了... (展开)
1659 70 221回应 收起
Zipporah 2006-06-23 14:19:47

## ROTK-the end of the journey

LOTR的第三部在新西兰的隆重首映，宣告着这一伟大的纪念碑式的作品的竣工，给我们带来了LOTR系列的终曲。 在此先澄清普遍流行的一个错误看法，即FOTR、TTT、ROTK是一部接着一部拍出来的，其实并非如此。LOTR三部曲并非如黑客帝国或HarryPorter系列那样几部分开拍摄，这三部... (展开)
600 23 35回应 收起
力克巧浣熊 2021-04-20 19:30:13

## 加长版和院线版的区别

这篇影评可能有剧透

写在重映之际，方便对两个版本区别有疑问的朋友 ------------------------------ 5月14日观影后更新 重映版上映后第一天去看了，发现大陆重映版本删除了奥克向米那斯提力斯扔人头的情节。需要指出的是，这一场景不仅存在于院线版之中，而且在2004年大陆上映时也存在，并未被删... (展开)
414 1 51回应 收起
瓜特 2012-12-22 23:56:31

## All for Sam

我去哪里找，像你这么好。 俗话说，王八瞅绿豆，对眼最重要。 身为一个在苦逼减肥的胖子， 我最爱的角色居然不是心心念念多年的王纸哥哥而是SAM小胖。 小胖看着一脸窝囊相，连和妹纸表白的勇气都没有，还要靠人推一把 当然……最后他成功抱得美人归证明自己是把妹界的好手... (展开)
433 7 56回应 收起
mado1983 2006-03-18 16:35:37

## 共醉魔戒

《指环王》三部曲以一年出一部的速度在2002—2005三年间，每年提醒我一次，去观看这个充满神奇幻想的中土世界。在分段观看的过程中，其实总有意犹未尽的感觉，因为一起观赏的朋友中总有人说只是特效比较令人赞赏而已，同时因为时间上的脱节，三部的剧情很难联系起来，每次看新... (展开)
342 19 40回应 收起
海边的西塞罗 2021-05-08 20:26:11

## 指环王密码：比“魔戒圣战”更壮阔的，是它的历史原型

这篇影评可能有剧透

及时阅读更新，请关注本人微信公众号：海边的西塞罗 而今，震天的战鼓再次敲响…… 本文接近一万字，但绝对读有所值，我将借解析指环王的剧情，为您梳理一下欧洲一段不为人知但至关重要的历史脉络。请在空闲时间阅读。 在上一篇文章《[《指环王》密码（上）：欧洲文明在惧怕谁... (展开)
274 2 29回应 收起
Zipporah 2006-02-09 12:47:35

## End of an Era

我没有读过原著，但如果你仔细看完整个Trilogy，你会发现它所包含的远远多于黑白两派的斗争，它有对人性弱点的剖析，对爱和友谊的赞美，对自然和环境的反思，它已经不是一个故事了，而是一部史诗。 不喜欢LOTR的人总说它商业味太浓，但我可以说这是我所看过所有的商业片中内涵... (展开)
228 12 23回应 收起
第一导演 2021-06-02 19:17:39

## 波米+导演杨超+法兰西胶片：悲伤告别《指环王》

撰文/法兰西胶片 大家好啊，六一儿童节快乐啊！三胎准备好了吗？ 不知道我们小时候六一节的快乐，和现在我儿子六一节的快乐，是不是同一件事。 但可以明确，很多儿时的经典，慢慢变得不再让人快乐。 今天我们就来最后一次聊聊“令人不快”的《指环王》（并不），目前三部曲重映... (展开)
103 1 14回应 收起
泥鳅也是蛇 2015-10-05 16:07:06

## 战争除了有牺牲和鲜血，还代表着希望

帕兰诺平原失守,刚铎统治者希优顿认为不应该放弃外围防守,因而不顾战争形势派小儿子法拉墨攻打已被魔多军团占领的沦陷区。魔多军团已经在论陷区装备齐全,半兽人整装待发。法拉墨的进攻无异于以卵击石,这是一场注定失败的攻击。但由于法拉墨为了表现他对国家的忠诚,为了... (展开)
80 2 8回应 收起

> 更多影评 1026篇

添加新讨论

## 讨论区 · · · · · ·

霍比屯萌宝中土游记 | 来自kxmd2009 | 11 回应 | 2022-11-18 12:32:42
所以为什么甘道夫不直接骑飞鸟带弗罗多去火山？ | 来自巴赤赤 | 25 回应 | 2022-11-16 14:17:43
影片最后弗洛多把指环王的最后篇章交给山姆来写有... | 来自大磨叽 | 15 回应 | 2022-11-16 13:34:07
第一步这个伏笔好优秀啊 | 来自百潋 |  | 2022-11-14 12:56:03
pipping闯祸精看得我想冲进电影杀了他 | 来自小珉 | 8 回应 | 2022-11-14 09:54:14

> 去这部影片的讨论区（全部367条）

## 关于《指环王3：王者无敌》的问题 · · · · · · ( 全部42个 )

- 为什么最后furodo不能留下来？ 5人回答
- 甘道夫是如何升级的？ 11人回答

> 全部42个问题

## 在哪儿看这部电影 · · · · · ·

- 腾讯视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【豆瓣五星电影集中营】(1/3) (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- {北美电影票房总排行} (荔枝超人)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)

## 谁在看这部电影 · · · · · ·

- LottyLee915
  14分钟前 想看
- 〔已注销〕
  18分钟前 看过
- lithium hydride
  19分钟前 看过

1238954人看过 / 161660人想看

订阅指环王3：王者无敌的评论:
feed: rss 2.0